#include "legato.h"
#include "interfaces.h"

/*
 * Test EnOcean
 *
 *  Created on: May 8, 2019
 *     Project: EnOcean
 *     Company: Energiya
 *      Author: Bartosz Cieslicki
 *      E-Mail: bartek@energiya.pl
 *         Tel: +48 505 148 375
 */

static void Event(uint8_t Packet, const uint8_t* Data, size_t Count, void* t)
{
	//Display received data
	LE_INFO("Receiving Start");
	char StrD[50];
	uint16_t Move = 0;
	int ii = 0;
	for (ii = 0; ii < Count; ii++)
	{
		Move+=sprintf(&StrD[Move], "%02x", Data[ii]);
	}
	StrD[Move] = '\0';
	LE_INFO(StrD);
	LE_INFO("Receiving End");
}

static void TimerHandler(le_timer_Ref_t timerRef)
{
	//Check Learn mode ( Description - page 49 of EnOcean Protocol )
	//If return 0001 Learn mode ON otherwise OFF
	const uint8_t DataLearnCheck[1] =  { 0x18 };
	const uint8_t OptionalDataLearnCheck[1] = { 0x00 };
	le_EnOcean_SendData(5, DataLearnCheck, 1, OptionalDataLearnCheck, 0);
}

COMPONENT_INIT
{
	sleep(10);

    le_EnOcean_AddOnReceiveHandler(Event, NULL);

    //Learn mode activation ( Description - page 48 of EnOcean Protocol )
	const uint8_t DataLearn[6] =  { 0x17, 0x01, 0x00, 0x00, 0x00, 0x00 };
	const uint8_t OptionalDataLearn[1] = { 0x00 };
	le_EnOcean_SendData(5, DataLearn, 6, OptionalDataLearn, 1);

	//Check Learn Mode 10 times every 10000 milliseconds
	le_timer_Ref_t TimerRef = le_timer_Create ("Check");
	le_timer_SetMsInterval(TimerRef, 10000);
	le_timer_SetRepeat(TimerRef, 10);
	le_timer_SetHandler(TimerRef, TimerHandler);
	le_timer_Start(TimerRef);
}
